@@ -2,6 +2,9 @@
 
 __all__ = []
 
+import logging
+
+logger = logging.getLogger(__name__)
 
 class Instrument():
 
